@@ -97,6 +97,7 @@ static PgCmd commands[] = {
     {"pg_dbinfo", "::pg::dbinfo", Pg_dbinfo,2},
     {"pg_getdata", "::pg::getdata", Pg_getdata,2},
     {"pg_sql", "::pg::sql", Pg_sql,2},
+    {"pg_copy_complete", "::pg::copy_complete", Pg_copy_complete, 3},
 #ifdef HAVE_SQLITE3
     {"pg_sqlite", "::pg::sqlite", Pg_sqlite, 3},
 #endif
@@ -159,7 +160,7 @@ Pgtcl_Init(Tcl_Interp *interp)
                     * No really good way to do error handling here, since we
                     * don't know how we were loaded
                     */
-                    return FALSE;
+                    return TCL_ERROR;
             }
 
     #endif
@@ -180,8 +181,10 @@ Pgtcl_Init(Tcl_Interp *interp)
 	if (tclversion >= 8.1)
 		Tcl_PutEnv("PGCLIENTENCODING=UNICODE");
 
-	/* register all pgtcl commands */
+	if(pgtclInitEncoding(interp) != TCL_OK)
+		return TCL_ERROR;
 
+	/* register all pgtcl commands */
 
 	for (cmdPtr = commands; cmdPtr->name != NULL; cmdPtr++) {
 		Tcl_CreateObjCommand(interp, cmdPtr->name, 
